#
# spec file for package python-django-filter
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-django-filter
Version:        2.3.0
Release:        bp153.1.22
Summary:        Reusable Django app to allow users to filter queryset dynamically
License:        BSD-3-Clause
Group:          Development/Libraries/Python
URL:            https://github.com/carltongibson/django-filter
Source:         https://files.pythonhosted.org/packages/source/d/django-filter/django-filter-%{version}.tar.gz
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module django-crispy-forms}
BuildRequires:  %{python_module djangorestframework}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django
Requires:       python-djangorestframework
Recommends:     python-django-crispy-forms
BuildArch:      noarch
%python_subpackages

%description
Django-filter is a reusable Django application for allowing users to filter queryset dynamically. It
requires Python 2.7 or higher. For usage and installation instructions, consult the docs directory.

%prep
%setup -q -n django-filter-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec runtests.py -v 2 

%files %{python_files}
%license LICENSE
%doc AUTHORS CHANGES.rst README.rst docs/{*.txt,ref/*.txt}
%{python_sitelib}/*

%changelog
* Tue Jun  9 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 2.3.0
  * Fixed import of FieldDoesNotExist.
  * Added testing against Django 3.0
  * Declared support for, and added testing against, Python 3.8
  * Fix filterset multiple inheritance bug
  * Allowed customising default lookup expression.
  * Fixed IsoDateTimeRangeFieldTests for Django 3.1
* Mon Sep 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.0:
  * Added DjangoFilterBackend.get_schema_operation_parameters() for DRF 3.10+
  * OpenAPI schema generation. (#1086)
  * Added lookup_expr to MultipleChoiceFilter (#1054)
  * Dropped support for EOL Python 3.4
- Remove merged patch fix_tests.patch
* Wed Apr 10 2019 Ondřej Súkup <mimi.vx@gmail.com>
- added fix_tests.patch - better compactibility with django 2.2
* Wed Feb 27 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.0:
  * Fixed a regression in FilterView introduced in 2.0. An empty QuerySet was incorrectly used whenever the FilterSet was unbound (i.e. when there were no GET parameters). The correct, pre-2.0 behaviour is now restored.
  * A workaround was to set strict=False on the FilterSet. This is no longer necessary, so you may restore strict behaviour as desired.
  * Added IsoDateTimeFromToRangeFilter. Allows From-To filtering using ISO-8601 formatted dates.
* Thu Nov 22 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid name repetition in summary.
* Thu Nov 22 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to version 2.0.0:
  * python 3.7 support
  * dropped py2 support
  * API changes
* Wed Dec 20 2017 fbergmann@suse.com
- Update to version 1.1.0
  * Add Deprecations for 2.0 (#792)
  * Improve IsoDateTimeField test clarity (#790)
  * Fix form attr references in tests (#789)
  * Simplify tox config, drop python 3.3 & django 1.8 (#787)
  * Make get_filter_name a classmethod, allowing it to be overriden for each FilterClass (#775)
  * Support active timezone (#750)
  * Docs Typo: django_filters -> filters in docs (#773)
  * Add Polish translations for some messages (#771)
  * Remove support for Django 1.9 (EOL) (#752)
  * Use required attribute from field when getting schema fields (#766)
  * Prevent circular ImportError hiding for rest_framework sub-package (#741)
  * Deprecate 'extra' field attrs on Filter (#734)
  * Add SuffixedMultiWidget (#681)
  * Fix null filtering for *Choice filters (#680)
  * Use isort on imports (#761)
  * Use urlencode from django.utils.http (#760)
  * Remove OrderingFilter.help_text (#757)
  * Update DRF test dependency to 3.6 (#747)
* Fri Sep 27 2013 p.drouand@gmail.com
- Update to version 0.7
  + FEATURE: Added support for AutoField
  + FEATURE: There is a "distinct" flag to ensure that only unique rows are
  returned
  + FEATURE: Support descending ordering (slighty backwards incompatible)
  + FEATURE: Support "strict" querysets, ie wrong filter data returns no results
  + FIXED: Some translation strings were changed to be in line with admin
  + FIXED: Support for Django 1.7
- Refactor specfile
- Use download url as source
- Replace python-ditribute with python-setuptools BuildRequires
- Add documentation from tarball
- Add a head in specfile
* Wed Mar 10 2010 alexandre@exatati.com.br
- Update to 0.5.3.
* Mon Nov 30 2009 alexandre@exatati.com.br
- Update to 0.5.2;
- Building as noarch for openSUSE >= 11.2.
* Tue Aug 25 2009 matrixworkstation@gmail.com
- Update to 0.5.1.
* Tue Aug 18 2009 alexandre@exatati.com.br
- Initial package (0.5.0) for openSUSE.
